@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2003-2021, by Barak Naveh, Dimitrios Michail and Contributors.
+ * (C) Copyright 2003-2023, by Barak Naveh, Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -389,10 +389,9 @@ public abstract class GraphTests
     public static <V, E> boolean isBipartitePartition(
         Graph<V, E> graph, Set<? extends V> firstPartition, Set<? extends V> secondPartition)
     {
-        return new BipartitePartitioning<>(graph)
-            .isValidPartitioning(
-                new PartitioningAlgorithm.PartitioningImpl<>(
-                    Arrays.asList((Set<V>) firstPartition, (Set<V>) secondPartition)));
+        return new BipartitePartitioning<>(graph).isValidPartitioning(
+            new PartitioningAlgorithm.PartitioningImpl<>(
+                Arrays.asList((Set<V>) firstPartition, (Set<V>) secondPartition)));
     }
 
     /**
