@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2020-2021, by Timofey Chudakov and Contributors.
+ * (C) Copyright 2020-2023, by Timofey Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -583,12 +583,9 @@ public class TreeDynamicConnectivity<T>
         @Override
         public String toString()
         {
-            return String
-                .format(
-                    "{%s} -> [%s]", value,
-                    arcs
-                        .stream().map(a -> a.target.value.toString())
-                        .collect(Collectors.joining(",")));
+            return String.format(
+                "{%s} -> [%s]", value,
+                arcs.stream().map(a -> a.target.value.toString()).collect(Collectors.joining(",")));
         }
     }
 
