@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Christoph Grüne and Contributors.
+ * (C) Copyright 2018-2023, by Christoph Grüne and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -305,8 +305,7 @@ public class AhujaOrlinSharmaCyclicExchangeLocalAugmentation<V, E>
      * @since June 7, 2018
      */
     private class LabeledPath<V>
-        implements
-        Cloneable
+        implements Cloneable
     {
 
         /**
