@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2016-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2016-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -45,8 +45,7 @@ import java.util.*;
  * @author Dimitrios Michail
  */
 public class HierholzerEulerianCycle<V, E>
-    implements
-    EulerianCycleAlgorithm<V, E>
+    implements EulerianCycleAlgorithm<V, E>
 {
     /*
      * The input graph.
