@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Alexandru Valeanu and Contributors.
+ * (C) Copyright 2018-2023, by Alexandru Valeanu and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -65,8 +65,7 @@ import java.util.*;
  * @param <E> the graph edge type
  */
 public class HeavyPathDecomposition<V, E>
-    implements
-    TreeToPathDecompositionAlgorithm<V, E>
+    implements TreeToPathDecompositionAlgorithm<V, E>
 {
 
     private final Graph<V, E> graph;
