@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2017-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2017-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -28,8 +28,7 @@ import java.util.*;
  * @author Dimitrios Michail
  */
 public interface MaximalCliqueEnumerationAlgorithm<V, E>
-    extends
-    Iterable<Set<V>>
+    extends Iterable<Set<V>>
 {
 
     /**
