@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2017-2021, by Joris Kinable and Contributors.
+ * (C) Copyright 2017-2023, by Joris Kinable and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -90,8 +90,7 @@ import java.util.stream.*;
  * @author Joris Kinable
  */
 public class DenseEdmondsMaximumCardinalityMatching<V, E>
-    implements
-    MatchingAlgorithm<V, E>
+    implements MatchingAlgorithm<V, E>
 {
     /* The graph we are matching on. */
     private final Graph<V, E> graph;
