@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2019-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2019-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -80,8 +80,7 @@ import java.util.*;
  * @author Joris Kinable
  */
 public class SparseEdmondsMaximumCardinalityMatching<V, E>
-    implements
-    MatchingAlgorithm<V, E>
+    implements MatchingAlgorithm<V, E>
 {
     private final Graph<V, E> graph;
     private MatchingAlgorithm<V, E> initializer;
