@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Timofey Chudakov and Contributors.
+ * (C) Copyright 2018-2023, by Timofey Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -912,10 +912,8 @@ class BlossomVInitializer<V, E>
                                 minusNode.addChild(plusNode, minusNode.matched, true);
 
                                 if (DEBUG) {
-                                    System.out
-                                        .println(
-                                            "New branch root is " + plusNode + ", eps = "
-                                                + branchEps);
+                                    System.out.println(
+                                        "New branch root is " + plusNode + ", eps = " + branchEps);
                                 }
                                 // Start a new branch
                                 currentNode = branchRoot = plusNode;
