@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Timofey Chudakov and Contributors.
+ * (C) Copyright 2018-2023, by Timofey Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -532,8 +532,7 @@ class BlossomVNode
      * example).
      */
     public class IncidentEdgeIterator
-        implements
-        Iterator<BlossomVEdge>
+        implements Iterator<BlossomVEdge>
     {
 
         /**
