@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2019-2021, by Semen Chudakov and Contributors.
+ * (C) Copyright 2019-2023, by Semen Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -49,7 +49,7 @@ import static org.jgrapht.alg.shortestpath.ContractionHierarchyPrecomputation.*;
  * restored actual path from the information in the shortest paths trees.
  *
  * <p>
- * Additionally if $|S| > |T|$ the algorithm is executed on the reversed graph. This allows to
+ * Additionally if $|S| &gt; |T|$ the algorithm is executed on the reversed graph. This allows to
  * reduce the number of buckets and optimize memory usage of the algorithm.
  *
  * <p>
@@ -67,8 +67,7 @@ import static org.jgrapht.alg.shortestpath.ContractionHierarchyPrecomputation.*;
  * @see DijkstraManyToManyShortestPaths
  */
 public class CHManyToManyShortestPaths<V, E>
-    extends
-    BaseManyToManyShortestPaths<V, E>
+    extends BaseManyToManyShortestPaths<V, E>
 {
     /**
      * Contraction hierarchy of {@code graph}.
@@ -84,18 +83,6 @@ public class CHManyToManyShortestPaths<V, E>
      */
     private Map<V, ContractionVertex<V>> contractionMapping;
 
-    /**
-     * Constructs an instance of the algorithm for a given {@code graph}.
-     *
-     * @param graph a graph
-     * @deprecated replaced with {@link #CHManyToManyShortestPaths(Graph, ThreadPoolExecutor)}
-     */
-    @Deprecated
-    public CHManyToManyShortestPaths(Graph<V, E> graph)
-    {
-        this(new ContractionHierarchyPrecomputation<>(graph).computeContractionHierarchy());
-    }
-
     /**
      * Constructs an instance of the algorithm for a given {@code graph} and {@code executor}. It is
      * up to a user of this algorithm to handle the creation and termination of the provided
@@ -353,8 +340,7 @@ public class CHManyToManyShortestPaths<V, E>
      * trees corresponding to source and target vertices.
      */
     private class CHManyToManyShortestPathsImpl
-        extends
-        BaseManyToManyShortestPathsImpl<V, E>
+        extends BaseManyToManyShortestPathsImpl<V, E>
     {
         /**
          * The underlying graph.
