@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2019-2021, by Semen Chudakov and Contributors.
+ * (C) Copyright 2019-2023, by Semen Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -69,8 +69,7 @@ import java.util.*;
  * @author Semen Chudakov
  */
 public class EppsteinShortestPathIterator<V, E>
-    implements
-    Iterator<GraphPath<V, E>>
+    implements Iterator<GraphPath<V, E>>
 {
     /**
      * Underlying graph.
@@ -138,11 +137,10 @@ public class EppsteinShortestPathIterator<V, E>
         GraphPath<V, E> shortestPath = shortestPaths.getPath(source);
         if (shortestPath != null) {
             distanceAndPredecessorMap = shortestPaths.getDistanceAndPredecessorMap();
-            pathsQueue
-                .add(
-                    new EppsteinGraphPath(
-                        graph, new ArrayList<>(0), distanceAndPredecessorMap,
-                        shortestPath.getWeight()));
+            pathsQueue.add(
+                new EppsteinGraphPath(
+                    graph, new ArrayList<>(0), distanceAndPredecessorMap,
+                    shortestPath.getWeight()));
             hMapping = new HashMap<>();
 
             buildPathsGraph();
@@ -223,10 +221,9 @@ public class EppsteinShortestPathIterator<V, E>
         List<PathsGraphVertex> sidetracks = new ArrayList<>(path.pathsGraphVertices);
         sidetracks.add(extendingVertex);
 
-        pathsQueue
-            .add(
-                new EppsteinGraphPath(
-                    graph, sidetracks, distanceAndPredecessorMap, path.weight + weight));
+        pathsQueue.add(
+            new EppsteinGraphPath(
+                graph, sidetracks, distanceAndPredecessorMap, path.weight + weight));
     }
 
     /**
@@ -266,9 +263,8 @@ public class EppsteinShortestPathIterator<V, E>
                         stack.removeLast();
                         insertVertex(v, null);
                     } else {
-                        V predecessor = Graphs
-                            .getOppositeVertex(
-                                graph, distanceAndPredecessorMap.get(v).getSecond(), v);
+                        V predecessor = Graphs.getOppositeVertex(
+                            graph, distanceAndPredecessorMap.get(v).getSecond(), v);
 
                         if (hMapping.containsKey(predecessor)) {
                             stack.removeLast();
@@ -533,9 +529,7 @@ public class EppsteinShortestPathIterator<V, E>
      * Represents a path that is generated during the computations.
      */
     private class EppsteinGraphPath
-        implements
-        GraphPath<V, E>,
-        Comparable<EppsteinGraphPath>
+        implements GraphPath<V, E>, Comparable<EppsteinGraphPath>
     {
 
         /**
@@ -700,8 +694,7 @@ public class EppsteinShortestPathIterator<V, E>
      * paths graph traversal.
      */
     private class PathsGraphVertex
-        implements
-        Comparable<PathsGraphVertex>
+        implements Comparable<PathsGraphVertex>
     {
 
         /**
