@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2020-2021, by Semen Chudakov and Contributors.
+ * (C) Copyright 2020-2023, by Semen Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -33,12 +33,12 @@ import java.util.function.ToDoubleFunction;
  * Dynamic programming algorithm for computing edit distance between trees.
  *
  * <p>
- * The algorithm is originally described in Zhang, Kaizhong & Shasha, Dennis. (1989). Simple Fast
- * Algorithms for the Editing Distance Between Trees and Related Problems. SIAM J. Comput.. 18.
+ * The algorithm is originally described in Zhang, Kaizhong &amp; Shasha, Dennis. (1989). Simple
+ * Fast Algorithms for the Editing Distance Between Trees and Related Problems. SIAM J. Comput.. 18.
  * 1245-1262. 10.1137/0218082.
  *
  * <p>
- * The time complexity of the algorithm if $O(|T_1|\cdot|T_2|\cdot min(depth(T_1),leaves(T_1)) \cdot
+ * The time complexity of the algorithm is $O(|T_1|\cdot|T_2|\cdot min(depth(T_1),leaves(T_1)) \cdot
  * min(depth(T_2),leaves(T_2)))$. Space complexity is $O(|T_1|\cdot |T_2|)$, where $|T_1|$ and
  * $|T_2|$ denote number of vertices in trees $T_1$ and $T_2$ correspondingly, $leaves()$ function
  * returns number of leaf vertices in a tree.
@@ -319,9 +319,8 @@ public class ZhangShashaTreeEditDistance<V, E>
 
                     forestdist[iIndex][jIndex] = result;
                     treeDistances[i1 - 1][j1 - 1] = result;
-                    editOperationLists
-                        .get(i1 - 1)
-                        .set(j1 - 1, restoreOperationsList(cachedOperations, iIndex, jIndex));
+                    editOperationLists.get(i1 - 1).set(
+                        j1 - 1, restoreOperationsList(cachedOperations, iIndex, jIndex));
                 } else {
                     int i2 = li1 - 1 - iOffset;
                     int j2 = lj1 - 1 - jOffset;
