@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2003-2021, by Barak Naveh and Contributors.
+ * (C) Copyright 2003-2023, by Barak Naveh and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -25,8 +25,7 @@ import java.util.*;
  * @author Barak Naveh
  */
 public class GraphChangeEvent
-    extends
-    EventObject
+    extends EventObject
 {
     private static final long serialVersionUID = 3834592106026382391L;
 
