@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2020-2021, by Timofey Chudakov and Contributors.
+ * (C) Copyright 2020-2023, by Timofey Chudakov and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -127,11 +127,9 @@ public class NetworkGeneratorConfigBuilder
     {
         if (Math.abs(value) > NetworkGenerator.CAPACITY_COST_BOUND) {
             invalidParam(
-                String
-                    .format(
-                        "Arcs capacities and cost must be between -%d and %d",
-                        NetworkGenerator.CAPACITY_COST_BOUND,
-                        NetworkGenerator.CAPACITY_COST_BOUND));
+                String.format(
+                    "Arcs capacities and cost must be between -%d and %d",
+                    NetworkGenerator.CAPACITY_COST_BOUND, NetworkGenerator.CAPACITY_COST_BOUND));
         }
         return value;
     }
