@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2008-2021, by Peter Giles and Contributors.
+ * (C) Copyright 2008-2023, by Peter Giles and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -17,14 +17,14 @@
  */
 package org.jgrapht.graph;
 
-import org.jgrapht.graph.builder.*;
-import org.jgrapht.traverse.*;
-import org.jgrapht.util.*;
-
 import java.io.*;
 import java.util.*;
 import java.util.function.*;
 
+import org.jgrapht.graph.builder.*;
+import org.jgrapht.traverse.*;
+import org.jgrapht.util.*;
+
 /**
  * A directed acyclic graph (DAG).
  *
@@ -60,15 +60,11 @@ import java.util.function.*;
  * @author Peter Giles
  */
 public class DirectedAcyclicGraph<V, E>
-    extends
-    AbstractBaseGraph<V, E>
-    implements
-    Iterable<V>
+    extends AbstractBaseGraph<V, E>
+    implements Iterable<V>
 {
     private static final long serialVersionUID = 4522128427004938150L;
 
-    private static final String EDGE_WOULD_INDUCE_A_CYCLE = "Edge would induce a cycle";
-
     private final Comparator<V> topoComparator;
     private final TopoOrderMap<V> topoOrderMap;
     private int maxTopoIndex = 0;
@@ -126,7 +122,25 @@ public class DirectedAcyclicGraph<V, E>
 
     /**
      * Construct a directed acyclic graph.
-     * 
+     *
+     * @param vertexSupplier the vertex supplier
+     * @param edgeSupplier the edge supplier
+     * @param weighted if true the graph will be weighted, otherwise not
+     * @param allowMultipleEdges if true the graph will allow multiple edges, otherwise not
+     * @param graphSpecificsStrategy strategy for constructing low-level graph specifics
+     */
+    public DirectedAcyclicGraph(
+        Supplier<V> vertexSupplier, Supplier<E> edgeSupplier, boolean weighted,
+        boolean allowMultipleEdges, GraphSpecificsStrategy<V, E> graphSpecificsStrategy)
+    {
+        this(
+            vertexSupplier, edgeSupplier, new VisitedBitSetImpl(), new TopoVertexBiMap<>(),
+            weighted, allowMultipleEdges, graphSpecificsStrategy);
+    }
+
+    /**
+     * Construct a directed acyclic graph.
+     *
      * @param vertexSupplier the vertex supplier
      * @param edgeSupplier the edge supplier
      * @param visitedStrategyFactory the visited strategy factory. Subclasses can change this
@@ -145,7 +159,7 @@ public class DirectedAcyclicGraph<V, E>
 
     /**
      * Construct a directed acyclic graph.
-     * 
+     *
      * @param vertexSupplier the vertex supplier
      * @param edgeSupplier the edge supplier
      * @param visitedStrategyFactory the visited strategy factory. Subclasses can change this
@@ -159,12 +173,37 @@ public class DirectedAcyclicGraph<V, E>
         Supplier<V> vertexSupplier, Supplier<E> edgeSupplier,
         VisitedStrategyFactory visitedStrategyFactory, TopoOrderMap<V> topoOrderMap,
         boolean weighted, boolean allowMultipleEdges)
+    {
+        this(
+            vertexSupplier, edgeSupplier, visitedStrategyFactory, topoOrderMap, weighted,
+            allowMultipleEdges, new FastLookupGraphSpecificsStrategy<>());
+    }
+
+    /**
+     * Construct a directed acyclic graph.
+     *
+     * @param vertexSupplier the vertex supplier
+     * @param edgeSupplier the edge supplier
+     * @param visitedStrategyFactory the visited strategy factory. Subclasses can change this
+     *        implementation to adjust the performance tradeoffs.
+     * @param topoOrderMap the topological order map. For performance reasons, subclasses can change
+     *        the way this class stores the topological order.
+     * @param weighted if true the graph will be weighted, otherwise not
+     * @param allowMultipleEdges if true the graph will allow multiple edges, otherwise not
+     * @param graphSpecificsStrategy strategy for constructing low-level graph specifics
+     */
+    protected DirectedAcyclicGraph(
+        Supplier<V> vertexSupplier, Supplier<E> edgeSupplier,
+        VisitedStrategyFactory visitedStrategyFactory, TopoOrderMap<V> topoOrderMap,
+        boolean weighted, boolean allowMultipleEdges,
+        GraphSpecificsStrategy<V, E> graphSpecificsStrategy)
     {
         super(
             vertexSupplier, edgeSupplier,
             new DefaultGraphType.Builder()
                 .directed().allowMultipleEdges(allowMultipleEdges).allowSelfLoops(false)
-                .weighted(weighted).allowCycles(false).build());
+                .weighted(weighted).allowCycles(false).build(),
+            graphSpecificsStrategy);
         this.visitedStrategyFactory =
             Objects.requireNonNull(visitedStrategyFactory, "Visited factory cannot be null");
         this.topoOrderMap =
@@ -188,7 +227,7 @@ public class DirectedAcyclicGraph<V, E>
 
     /**
      * Create a builder for this kind of graph.
-     * 
+     *
      * @param edgeSupplier edge supplier for the edges
      * @param <V> the graph vertex type
      * @param <E> the graph edge type
@@ -270,7 +309,8 @@ public class DirectedAcyclicGraph<V, E>
      * the "affected region", and should in general be faster than recomputing the whole topological
      * ordering from scratch.
      *
-     * @throws IllegalArgumentException if the edge would induce a cycle in the graph
+     * @throws IllegalArgumentException if the vertex is not in the graph
+     * @throws GraphCycleProhibitedException if the vertex would induce a cycle in the graph
      */
     @Override
     public E addEdge(V sourceVertex, V targetVertex)
@@ -278,14 +318,12 @@ public class DirectedAcyclicGraph<V, E>
         assertVertexExist(sourceVertex);
         assertVertexExist(targetVertex);
 
-        E result;
         try {
             updateDag(sourceVertex, targetVertex);
-            result = super.addEdge(sourceVertex, targetVertex);
+            return super.addEdge(sourceVertex, targetVertex);
         } catch (CycleFoundException e) {
-            throw new IllegalArgumentException(EDGE_WOULD_INDUCE_A_CYCLE);
+            throw new GraphCycleProhibitedException();
         }
-        return result;
     }
 
     /**
@@ -296,7 +334,8 @@ public class DirectedAcyclicGraph<V, E>
      * the "affected region", and should in general be faster than recomputing the whole topological
      * ordering from scratch.
      *
-     * @throws IllegalArgumentException if the edge would induce a cycle in the graph
+     * @throws IllegalArgumentException if the vertex is not in the graph
+     * @throws GraphCycleProhibitedException if the vertex would induce a cycle in the graph
      */
     @Override
     public boolean addEdge(V sourceVertex, V targetVertex, E e)
@@ -310,14 +349,12 @@ public class DirectedAcyclicGraph<V, E>
         assertVertexExist(sourceVertex);
         assertVertexExist(targetVertex);
 
-        boolean result;
         try {
             updateDag(sourceVertex, targetVertex);
-            result = super.addEdge(sourceVertex, targetVertex, e);
+            return super.addEdge(sourceVertex, targetVertex, e);
         } catch (CycleFoundException ex) {
-            throw new IllegalArgumentException(EDGE_WOULD_INDUCE_A_CYCLE);
+            throw new GraphCycleProhibitedException();
         }
-        return result;
     }
 
     /**
@@ -368,6 +405,7 @@ public class DirectedAcyclicGraph<V, E>
      *
      * @return a topological order iterator
      */
+    @Override
     public Iterator<V> iterator()
     {
         return new TopoIterator();
@@ -584,8 +622,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected interface TopoOrderMap<V>
-        extends
-        Serializable
+        extends Serializable
     {
         /**
          * Add a vertex at the given topological index.
@@ -672,8 +709,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected interface VisitedStrategyFactory
-        extends
-        Serializable
+        extends Serializable
     {
         /**
          * Create a new instance of {@link VisitedStrategy}.
@@ -690,8 +726,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected static class TopoVertexBiMap<V>
-        implements
-        TopoOrderMap<V>
+        implements TopoOrderMap<V>
     {
         private static final long serialVersionUID = 1L;
 
@@ -750,8 +785,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected class TopoVertexMap
-        implements
-        TopoOrderMap<V>
+        implements TopoOrderMap<V>
     {
         private static final long serialVersionUID = 1L;
 
@@ -830,8 +864,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected static class Region
-        implements
-        Serializable
+        implements Serializable
     {
         private static final long serialVersionUID = 1L;
 
@@ -906,9 +939,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author John V. Sichi
      */
     protected static class VisitedBitSetImpl
-        implements
-        VisitedStrategy,
-        VisitedStrategyFactory
+        implements VisitedStrategy, VisitedStrategyFactory
     {
         private static final long serialVersionUID = 1L;
 
@@ -973,9 +1004,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected static class VisitedArrayListImpl
-        implements
-        VisitedStrategy,
-        VisitedStrategyFactory
+        implements VisitedStrategy, VisitedStrategyFactory
     {
         private static final long serialVersionUID = 1L;
 
@@ -1047,9 +1076,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected static class VisitedHashSetImpl
-        implements
-        VisitedStrategy,
-        VisitedStrategyFactory
+        implements VisitedStrategy, VisitedStrategyFactory
     {
         private static final long serialVersionUID = 1L;
 
@@ -1099,9 +1126,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     protected static class VisitedArrayImpl
-        implements
-        VisitedStrategy,
-        VisitedStrategyFactory
+        implements VisitedStrategy, VisitedStrategyFactory
     {
         private static final long serialVersionUID = 1L;
 
@@ -1166,8 +1191,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     private static class CycleFoundException
-        extends
-        Exception
+        extends Exception
     {
         private static final long serialVersionUID = 5583471522212552754L;
     }
@@ -1178,9 +1202,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     private class TopoComparator
-        implements
-        Comparator<V>,
-        Serializable
+        implements Comparator<V>, Serializable
     {
         private static final long serialVersionUID = 8144905376266340066L;
 
@@ -1199,8 +1221,7 @@ public class DirectedAcyclicGraph<V, E>
      * @author Peter Giles
      */
     private class TopoIterator
-        implements
-        Iterator<V>
+        implements Iterator<V>
     {
         private int currentTopoIndex;
         private final long expectedTopoModCount = topoModCount;
