@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2021-2021, by Hannes Wellmann and Contributors.
+ * (C) Copyright 2021-2023, by Hannes Wellmann and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -23,8 +23,7 @@ package org.jgrapht.graph;
  * @author Hannes Wellmann
  */
 public class IntrusiveEdgeException
-    extends
-    RuntimeException
+    extends RuntimeException
 {
     private static final long serialVersionUID = 7261763645809925025L;
 
