@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2017-2021, by Joris Kinable and Contributors.
+ * (C) Copyright 2017-2023, by Joris Kinable and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -21,8 +21,7 @@ package org.jgrapht.graph;
  * Exception thrown in the event that the path is invalid.
  */
 public class InvalidGraphWalkException
-    extends
-    RuntimeException
+    extends RuntimeException
 {
     private static final long serialVersionUID = 3811666107707436479L;
 
