@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2003-2021, by Barak Naveh and Contributors.
+ * (C) Copyright 2003-2023, by Barak Naveh and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -33,9 +33,7 @@ import java.util.*;
  * @author Barak Naveh
  */
 public class ArrayUnenforcedSetEdgeSetFactory<V, E>
-    implements
-    EdgeSetFactory<V, E>,
-    Serializable
+    implements EdgeSetFactory<V, E>, Serializable
 {
     private static final long serialVersionUID = 5936902837403445985L;
 
