@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2021-2021, by Hannes Wellmann and Contributors.
+ * (C) Copyright 2021-2023, by Hannes Wellmann and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -25,8 +25,7 @@ import java.util.function.*;
  * @author Hannes Wellmann
  */
 public class SupplierException
-    extends
-    IllegalArgumentException
+    extends IllegalArgumentException
 {
     private static final long serialVersionUID = -8192314371524515620L;
 
