@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2017-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2017-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -29,8 +29,7 @@ import java.util.*;
  * @author Dimitrios Michail
  */
 public class RandomGreedyColoring2Test
-    extends
-    BaseColoringTest
+    extends BaseColoringTest
 {
 
     final long seed = 15;
