@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2016-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2016-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -556,9 +556,8 @@ public class StackBFSFundamentalCycleBasisTest
     public void test1()
     {
         Graph<Integer, DefaultEdge> graph = new SimpleGraph<>(DefaultEdge.class);
-        Graphs
-            .addAllVertices(
-                graph, IntStream.rangeClosed(1, 7).boxed().collect(Collectors.toList()));
+        Graphs.addAllVertices(
+            graph, IntStream.rangeClosed(1, 7).boxed().collect(Collectors.toList()));
         graph.addEdge(1, 2);
         graph.addEdge(1, 3);
         graph.addEdge(2, 4);
