@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Alexandru Valeanu and Contributors.
+ * (C) Copyright 2018-2023, by Alexandru Valeanu and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -28,8 +28,7 @@ import java.util.*;
  * @author Alexandru Valeanu
  */
 public class HeavyPathLCAFinderTest
-    extends
-    LCATreeTestBase
+    extends LCATreeTestBase
 {
 
     @Override
