@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2012-2021, by Joris Kinable and Contributors.
+ * (C) Copyright 2012-2023, by Joris Kinable and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -30,8 +30,7 @@ import java.util.*;
  *
  */
 public class HopcroftKarpMaximumCardinalityBipartiteMatchingTest
-    extends
-    MaximumCardinalityBipartiteMatchingTest
+    extends MaximumCardinalityBipartiteMatchingTest
 {
 
     @Override
