@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2016-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2016-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -27,8 +27,7 @@ import org.jgrapht.graph.*;
  * @author Dimitrios Michail
  */
 public class PathGrowingWeightedMatchingTest
-    extends
-    BasePathGrowingWeightedMatchingTest
+    extends BasePathGrowingWeightedMatchingTest
 {
 
     @Override
