@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Assaf Mizrachi and Contributors.
+ * (C) Copyright 2018-2023, by Assaf Mizrachi and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -27,8 +27,7 @@ import org.jgrapht.alg.interfaces.*;
  * @author Assaf Mizrachi
  */
 public class SuurballeKDisjointShortestPathsTest
-    extends
-    KDisjointShortestPathsTestCase
+    extends KDisjointShortestPathsTestCase
 {
 
     @Override
