@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Alexandru Valeanu and Contributors.
+ * (C) Copyright 2018-2023, by Alexandru Valeanu and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -22,8 +22,7 @@ import org.jgrapht.alg.interfaces.*;
 import org.jgrapht.graph.*;
 
 public class PrimMinimumSpanningTreeTest
-    extends
-    MinimumSpanningTreeTest
+    extends MinimumSpanningTreeTest
 {
 
     @Override
