@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Alexandru Valeanu and Contributors.
+ * (C) Copyright 2018-2023, by Alexandru Valeanu and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -23,8 +23,7 @@ import org.jgrapht.alg.interfaces.*;
 import java.util.*;
 
 public class ClarksonTwoApproxVCImplTest
-    extends
-    WeightedVertexCoverTwoApproxTest
+    extends WeightedVertexCoverTwoApproxTest
 {
 
     @Override
