@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2018-2021, by Alexandru Valeanu and Contributors.
+ * (C) Copyright 2018-2023, by Alexandru Valeanu and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -21,8 +21,7 @@ import org.jgrapht.*;
 import org.jgrapht.alg.interfaces.*;
 
 public class EdgeBasedTwoApproxVCImplTest
-    extends
-    VertexCoverTwoApproxTest
+    extends VertexCoverTwoApproxTest
 {
     @Override
     public <V, E> VertexCoverAlgorithm<V> createSolver(Graph<V, E> graph)
