@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2005-2021, by Assaf Lehr, Dimitrios Michail and Contributors.
+ * (C) Copyright 2005-2023, by Assaf Lehr, Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -367,11 +367,10 @@ public class GnmRandomGraphGeneratorTest
     {
         List<Graph<Integer, DefaultEdge>> graphArray = new ArrayList<>();
         for (int i = 0; i < 4; ++i) {
-            graphArray
-                .add(
-                    new SimpleDirectedGraph<>(
-                        SupplierUtil.createIntegerSupplier(),
-                        SupplierUtil.createDefaultEdgeSupplier(), false));
+            graphArray.add(
+                new SimpleDirectedGraph<>(
+                    SupplierUtil.createIntegerSupplier(), SupplierUtil.createDefaultEdgeSupplier(),
+                    false));
         }
 
         generateGraphs(graphArray, 11, 100);
@@ -391,12 +390,11 @@ public class GnmRandomGraphGeneratorTest
     {
         List<Graph<Integer, DefaultEdge>> graphArray = new ArrayList<>();
         for (int i = 0; i < 4; ++i) {
-            graphArray
-                .add(
-                    new DefaultListenableGraph<>(
-                        new SimpleGraph<>(
-                            SupplierUtil.createIntegerSupplier(),
-                            SupplierUtil.createDefaultEdgeSupplier(), false)));
+            graphArray.add(
+                new DefaultListenableGraph<>(
+                    new SimpleGraph<>(
+                        SupplierUtil.createIntegerSupplier(),
+                        SupplierUtil.createDefaultEdgeSupplier(), false)));
         }
 
         generateGraphs(graphArray, 11, 50);
