@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2008-2021, by Peter Giles and Contributors.
+ * (C) Copyright 2008-2023, by Peter Giles and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -66,7 +66,7 @@ public class DirectedAcyclicGraphTest
                 boolean dagRejectedEdge = false;
                 try {
                     dag.addEdge(edgeSource, edgeTarget);
-                } catch (IllegalArgumentException e) {
+                } catch (GraphCycleProhibitedException e) {
                     // okay, it did't add that edge
                     dagRejectedEdge = true;
                 }
@@ -601,6 +601,57 @@ public class DirectedAcyclicGraphTest
 
     }
 
+    @Test
+    public void testFastLookupGraphSpecificsStrategyAndArrayUnenforcedSet()
+    {
+        GraphSpecificsStrategy<String, DefaultEdge> graphSpecificsStrategy =
+            new FastLookupGraphSpecificsStrategy<>();
+        DirectedAcyclicGraph<String,
+            DefaultEdge> graph = new DirectedAcyclicGraph<>(
+                SupplierUtil.createStringSupplier(), SupplierUtil.DEFAULT_EDGE_SUPPLIER, false,
+                false, graphSpecificsStrategy);
+        String a = "A";
+        String b = "B";
+
+        graph.addVertex(a);
+        graph.addVertex(b);
+
+        graph.addEdge(a, b);
+
+        Iterator<String> it = graph.iterator();
+        assertEquals(a, it.next());
+        assertEquals(b, it.next());
+    }
+
+    @Test
+    public void testFastLookupGraphSpecificsStrategyAndHashSet()
+    {
+        GraphSpecificsStrategy<String, DefaultEdge> graphSpecificsStrategy =
+            new FastLookupGraphSpecificsStrategy<>()
+            {
+                @Override
+                public EdgeSetFactory<String, DefaultEdge> getEdgeSetFactory()
+                {
+                    return vertex -> new HashSet<>();
+                }
+            };
+        DirectedAcyclicGraph<String,
+            DefaultEdge> graph = new DirectedAcyclicGraph<>(
+                SupplierUtil.createStringSupplier(), SupplierUtil.DEFAULT_EDGE_SUPPLIER, false,
+                false, graphSpecificsStrategy);
+        String a = "A";
+        String b = "B";
+
+        graph.addVertex(a);
+        graph.addVertex(b);
+
+        graph.addEdge(a, b);
+
+        Iterator<String> it = graph.iterator();
+        assertEquals(a, it.next());
+        assertEquals(b, it.next());
+    }
+
     // ~ Private Methods ----------------------------------------------------------
 
     private Graph<Long, DefaultEdge> setUpWithSeed(int vertices, int edges, long seed)
@@ -683,8 +734,7 @@ public class DirectedAcyclicGraphTest
     // it is nice for tests to be easily repeatable, so we use a graph generator
     // that we can seed for specific configurations
     public static class RepeatableRandomGraphGenerator<V, E>
-        implements
-        GraphGenerator<V, E, V>
+        implements GraphGenerator<V, E, V>
     {
         private Random randomizer;
         private int numOfVertexes;
