@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2016-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2016-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -43,10 +43,8 @@ import java.util.Map.Entry;
  * @author Dimitrios Michail
  */
 public class DOTEventDrivenImporter
-    extends
-    BaseEventDrivenImporter<String, Pair<String, String>>
-    implements
-    EventDrivenImporter<String, Pair<String, String>>
+    extends BaseEventDrivenImporter<String, Pair<String, String>>
+    implements EventDrivenImporter<String, Pair<String, String>>
 {
     /**
      * Default key used for the graph ID.
@@ -54,7 +52,7 @@ public class DOTEventDrivenImporter
     public static final String DEFAULT_GRAPH_ID_KEY = "ID";
 
     // identifier unescape rule
-    private final CharSequenceTranslator UNESCAPE_ID;
+    private final CharSequenceTranslator unescapeId;
 
     private boolean notifyVertexAttributesOutOfOrder;
     private boolean notifyEdgeAttributesOutOfOrder;
@@ -84,7 +82,7 @@ public class DOTEventDrivenImporter
         lookupMap.put("\\\"", "\"");
         lookupMap.put("\\'", "'");
         lookupMap.put("\\", "");
-        UNESCAPE_ID = new AggregateTranslator(new LookupTranslator(lookupMap));
+        unescapeId = new AggregateTranslator(new LookupTranslator(lookupMap));
 
         this.notifyVertexAttributesOutOfOrder = notifyVertexAttributesOutOfOrder;
         this.notifyEdgeAttributesOutOfOrder = notifyEdgeAttributesOutOfOrder;
@@ -133,8 +131,7 @@ public class DOTEventDrivenImporter
      * Common error listener for both lexer and parser which throws an exception.
      */
     private class ThrowingErrorListener
-        extends
-        BaseErrorListener
+        extends BaseErrorListener
     {
         @Override
         public void syntaxError(
@@ -152,8 +149,7 @@ public class DOTEventDrivenImporter
      * grammar.
      */
     private class NotifyDOTListener
-        extends
-        DOTBaseListener
+        extends DOTBaseListener
     {
         private Set<String> vertices;
 
@@ -784,12 +780,12 @@ public class DOTEventDrivenImporter
      */
     private String unescapeId(String input)
     {
-        final char QUOTE = '"';
-        if (input.charAt(0) != QUOTE || input.charAt(input.length() - 1) != QUOTE) {
+        final char quote = '"';
+        if (input.charAt(0) != quote || input.charAt(input.length() - 1) != quote) {
             return input;
         }
         String noQuotes = input.subSequence(1, input.length() - 1).toString();
-        String unescaped = UNESCAPE_ID.translate(noQuotes);
+        String unescaped = unescapeId.translate(noQuotes);
         return unescaped;
     }
 
