@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2020-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2020-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -93,10 +93,8 @@ import java.util.*;
  * @author Dimitrios Michail
  */
 public class SimpleGEXFEventDrivenImporter
-    extends
-    BaseEventDrivenImporter<String, Triple<String, String, Double>>
-    implements
-    EventDrivenImporter<String, Triple<String, String, Double>>
+    extends BaseEventDrivenImporter<String, Triple<String, String, Double>>
+    implements EventDrivenImporter<String, Triple<String, String, Double>>
 {
     private static final List<String> SCHEMA_FILENAMES = List.of("viz.xsd", "gexf.xsd");
 
@@ -143,8 +141,8 @@ public class SimpleGEXFEventDrivenImporter
             notifyImportEvent(ImportEvent.START);
             xmlReader.parse(new InputSource(input));
             notifyImportEvent(ImportEvent.END);
-        } catch (Exception se) {
-            throw new ImportException("Failed to parse GEXF", se);
+        } catch (Exception e) {
+            throw new ImportException("Failed to parse GEXF", e);
         }
     }
 
@@ -162,6 +160,9 @@ public class SimpleGEXFEventDrivenImporter
 
         SchemaFactory factory = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
 
+        // disable DOCTYPE declaration
+        factory.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
+
         return factory.newSchema(sources);
     }
 
@@ -178,28 +179,30 @@ public class SimpleGEXFEventDrivenImporter
 
             // create reader
             return saxParser.getXMLReader();
-        } catch (Exception se) {
-            throw new ImportException("Failed to parse GEXF", se);
+        } catch (Exception e) {
+            throw new ImportException("Failed to parse GEXF", e);
         }
     }
 
+    private static final List<String> GRAPH_ATTRS =
+        List.of("defaultedgetype", "timeformat", "mode", "start", "end");
+    private static final List<String> NODE_ATTRS = List.of("label", "pid");
+    private static final List<String> EDGE_ATTRS = List.of("type", "label");
+
     // content handler
     private class GEXFHandler
-        extends
-        DefaultHandler
+        extends DefaultHandler
     {
         private static final String GRAPH = "graph";
-        private final List<String> GRAPH_ATTRS =
-            List.of("defaultedgetype", "timeformat", "mode", "start", "end");
+
         private static final String NODE = "node";
         private static final String NODE_ID = "id";
-        private final List<String> NODE_ATTRS = List.of("label", "pid");
+
         private static final String EDGE = "edge";
         private static final String EDGE_ID = "id";
         private static final String EDGE_SOURCE = "source";
         private static final String EDGE_TARGET = "target";
         private static final String EDGE_WEIGHT = "weight";
-        private final List<String> EDGE_ATTRS = List.of("type", "label");
 
         private static final String ATTRIBUTES = "attributes";
         private static final String ATTRIBUTES_CLASS = "class";
@@ -269,9 +272,8 @@ public class SimpleGEXFEventDrivenImporter
             case NODE:
                 insideNode++;
                 if (insideNode == 1 ^ insideEdge == 1) {
-                    String nodeId = findAttribute(NODE_ID, attributes)
-                        .orElseThrow(
-                            () -> new IllegalArgumentException("Node must have an identifier"));
+                    String nodeId = findAttribute(NODE_ID, attributes).orElseThrow(
+                        () -> new IllegalArgumentException("Node must have an identifier"));
                     currentNode = nodeId;
                     notifyVertex(currentNode);
                     for (String attrName : NODE_ATTRS) {
@@ -329,9 +331,8 @@ public class SimpleGEXFEventDrivenImporter
             case ATTRIBUTES:
                 insideAttributes++;
                 if (insideGraph == 1 && insideAttributes == 1) {
-                    attributesClass = findAttribute(ATTRIBUTES_CLASS, attributes)
-                        .orElseThrow(
-                            () -> new IllegalArgumentException("Attributes class missing"));
+                    attributesClass = findAttribute(ATTRIBUTES_CLASS, attributes).orElseThrow(
+                        () -> new IllegalArgumentException("Attributes class missing"));
                 }
                 break;
             case ATTRIBUTE:
