@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2006-2021, by John V Sichi and Contributors.
+ * (C) Copyright 2006-2023, by John V Sichi and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -295,8 +295,7 @@ public class GmlExporterTest
 
     @Test
     public void testUndirected()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         Graph<String, DefaultEdge> g = new SimpleGraph<String, DefaultEdge>(DefaultEdge.class);
         g.addVertex(V1);
@@ -315,8 +314,7 @@ public class GmlExporterTest
 
     @Test
     public void testUnweightedUndirected()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         Graph<String, DefaultEdge> g = new SimpleGraph<>(DefaultEdge.class);
         g.addVertex(V1);
@@ -336,8 +334,7 @@ public class GmlExporterTest
 
     @Test
     public void testDirected()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         Graph<String, DefaultEdge> g = new SimpleDirectedGraph<>(DefaultEdge.class);
         g.addVertex(V1);
@@ -361,8 +358,7 @@ public class GmlExporterTest
 
     @Test
     public void testWeightedUndirected()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         SimpleGraph<String, DefaultWeightedEdge> g =
             new SimpleWeightedGraph<String, DefaultWeightedEdge>(DefaultWeightedEdge.class);
@@ -385,8 +381,7 @@ public class GmlExporterTest
 
     @Test
     public void testWeightedUndirectedWithEdgeLabels()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         SimpleGraph<String, DefaultWeightedEdge> g =
             new SimpleWeightedGraph<>(DefaultWeightedEdge.class);
@@ -410,8 +405,7 @@ public class GmlExporterTest
 
     @Test
     public void testUndirectedWithVertexLabels()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         SimpleGraph<String, DefaultWeightedEdge> g =
             new SimpleWeightedGraph<>(DefaultWeightedEdge.class);
@@ -456,8 +450,7 @@ public class GmlExporterTest
 
     @Test
     public void testUndirectedWithCustomVertexAttributesAndVertexLabels()
-        throws UnsupportedEncodingException,
-        ExportException
+        throws UnsupportedEncodingException, ExportException
     {
         SimpleGraph<String, DefaultWeightedEdge> g =
             new SimpleWeightedGraph<>(DefaultWeightedEdge.class);
