@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2016-2021, by Dimitrios Michail and Contributors.
+ * (C) Copyright 2016-2023, by Dimitrios Michail and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -466,9 +466,7 @@ public class GmlImporterTest
 
     @Test
     public void testExportImport()
-        throws ImportException,
-        ExportException,
-        UnsupportedEncodingException
+        throws ImportException, ExportException, UnsupportedEncodingException
     {
         DirectedWeightedPseudograph<String, DefaultWeightedEdge> g1 =
             new DirectedWeightedPseudograph<>(DefaultWeightedEdge.class);
