@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2020-2021, by Hannes Wellmann and Contributors.
+ * (C) Copyright 2020-2023, by Hannes Wellmann and Contributors.
  *
  * JGraphT : a free Java graph-theory library
  *
@@ -22,8 +22,8 @@ import org.jgrapht.*;
 import org.jgrapht.alg.util.*;
 import org.jgrapht.graph.*;
 import org.jgrapht.nio.*;
-import org.jgrapht.nio.tsplib.TSPLIBImporter.Node;
 import org.jgrapht.nio.tsplib.TSPLIBImporter.*;
+import org.jgrapht.nio.tsplib.TSPLIBImporter.Node;
 import org.junit.*;
 
 import java.io.*;
@@ -65,9 +65,8 @@ public class TSPLIBImporterTest
         public String toString()
         {
             String indexStr = index >= 0 ? indexFormat.format(index) + " " : "";
-            return indexStr + Arrays
-                .stream(elements).mapToObj(coordinateFormat::format)
-                .collect(Collectors.joining(" "));
+            return indexStr + Arrays.stream(elements).mapToObj(coordinateFormat::format).collect(
+                Collectors.joining(" "));
         }
     }
 
@@ -87,10 +86,9 @@ public class TSPLIBImporterTest
 
     private static List<TestVector> getExpected3DPoints()
     {
-        return Arrays
-            .asList(
-                new TestVector(1, 10.0, 15.0, 3.7), new TestVector(2, 14.0, 15.0, 3.7),
-                new TestVector(3, 14.0, 20.0, 3.7), new TestVector(4, 14.0, 20.0, 3.7));
+        return Arrays.asList(
+            new TestVector(1, 10.0, 15.0, 3.7), new TestVector(2, 14.0, 15.0, 3.7),
+            new TestVector(3, 14.0, 20.0, 3.7), new TestVector(4, 14.0, 20.0, 3.7));
     }
 
     private static StringJoiner get2DPointsFileContent(String edgeWeightType)
@@ -102,18 +100,17 @@ public class TSPLIBImporterTest
         fileContent.add("NODE_COORD_SECTION");
         fileContent.add("1 10.2 15.0");
         fileContent.add("2 14.2 15.0");
-        fileContent.add("3 14.8 20.0");
-        fileContent.add("4 10.8 20.0");
+        fileContent.add("3  14.8    20.0"); // also use other white-space than just a single space
+        fileContent.add("4\t10.8\t\t20.0");
         fileContent.add("EOF");
         return fileContent;
     }
 
     private static List<TestVector> getExpected2DPoints()
     {
-        return Arrays
-            .asList(
-                new TestVector(1, 10.2, 15.0), new TestVector(2, 14.2, 15.0),
-                new TestVector(3, 14.8, 20.0), new TestVector(4, 10.8, 20.0));
+        return Arrays.asList(
+            new TestVector(1, 10.2, 15.0), new TestVector(2, 14.2, 15.0),
+            new TestVector(3, 14.8, 20.0), new TestVector(4, 10.8, 20.0));
     }
 
     // ----------------------------------------------------------------------
@@ -158,6 +155,43 @@ public class TSPLIBImporterTest
         assertTrue(metaData.hasDistinctNeighborDistances());
     }
 
+    @Test
+    public void testMetaDataValues_slightyOfSpecMetadata()
+    {
+        // The metadata/specification section of the following file is slightly off the standard
+        // containing changes that were observed in the wild.
+        StringJoiner fileContent = new StringJoiner(System.lineSeparator());
+        fileContent.add("NAME : theNameOfThisFile");
+        fileContent.add("TYPE : TSP (Some comment)");
+        fileContent.add("DIMENSION : 4 (Comment: number of elements)");
+        fileContent.add("EDGE_WEIGHT_TYPE : EUC_2D #use 2D edges");
+        fileContent.add("NODE_COORD_TYPE: THREED_COORDS");
+        fileContent.add("CAPACITY : 7 # Capacitated vehicle routing problem data");
+        fileContent.add("EDGE_WEIGHT_FORMAT: FULL_MATRIX");
+        fileContent.add("EDGE_DATA_FORMAT: ADJ_LIST");
+        fileContent.add("DISPLAY_DATA_TYPE : TWOD_DISPLAY");
+        fileContent.add("NODE_COORD_SECTION");
+        fileContent.add("1   10.2\t15.0");
+        fileContent.add("EOF");
+
+        Metadata<Object, DefaultWeightedEdge> metaData =
+            importGraphFromFile(fileContent).getSecond();
+
+        Specification spec = metaData.getSpecification();
+        assertEquals("theNameOfThisFile", spec.getName());
+        assertEquals("TSP", spec.getType());
+        assertEquals(Integer.valueOf(4), spec.getDimension());
+        assertEquals(Integer.valueOf(7), spec.getCapacity());
+        assertEquals("EUC_2D", spec.getEdgeWeightType());
+        assertEquals("FULL_MATRIX", spec.getEdgeWeightFormat());
+        assertEquals("ADJ_LIST", spec.getEdgeDataFormat());
+        assertEquals("THREED_COORDS", spec.getNodeCoordType());
+        assertEquals("TWOD_DISPLAY", spec.getDisplayDataType());
+
+        assertTrue(metaData.hasDistinctNodeLocations());
+        assertTrue(metaData.hasDistinctNeighborDistances());
+    }
+
     @Test
     public void testImportGraph_withNodeCoordSection()
     {
@@ -546,10 +580,10 @@ public class TSPLIBImporterTest
     public void testImportGraph_invalidSpecificationValue_ImportException()
     {
         StringJoiner fileContent = new StringJoiner(System.lineSeparator());
-        fileContent.add("EDGE_WEIGHT_FORMAT : some String");
+        fileContent.add("EDGE_WEIGHT_FORMAT : some_String");
 
         RuntimeException expectedCause =
-            new IllegalArgumentException("Invalid EDGE_WEIGHT_FORMAT value <some String>");
+            new IllegalArgumentException("Invalid EDGE_WEIGHT_FORMAT value <some_String>");
 
         expectGraphImportFailedException(() -> importGraphFromFile(fileContent), expectedCause);
     }
