@@ -174,8 +174,10 @@ public class SuccinctDirectedGraph
         final int numVertices, final List<Pair<Integer, Integer>> edges,
         final boolean incomingEdgesSupport)
     {
-        this(new SparseIntDirectedGraph(numVertices, edges, incomingEdgesSupport ? IncomingEdgesSupport.FULL_INCOMING_EDGES
-            : IncomingEdgesSupport.NO_INCOMING_EDGES));
+        this(
+            new SparseIntDirectedGraph(
+                numVertices, edges, incomingEdgesSupport ? IncomingEdgesSupport.FULL_INCOMING_EDGES
+            : IncomingEdgesSupport.NO_INCOMING_EDGES), incomingEdgesSupport);
     }
 
     /**
@@ -523,11 +525,11 @@ public class SuccinctDirectedGraph
         }
     }
 
-    private final GraphIterables<Integer, IntIntPair> ITERABLES = new SuccinctGraphIterables(this);
+    private final GraphIterables<Integer, IntIntPair> iterables = new SuccinctGraphIterables(this);
 
     @Override
     public GraphIterables<Integer, IntIntPair> iterables()
     {
-        return ITERABLES;
+        return iterables;
     }
 }
